@@ -22,11 +22,15 @@ use HTML::TreeBuilder;
 use parent 'Exporter';
 our @EXPORT_OK = qw( sro sro_en sro_ok );
 
-our $VERSION = '0.05';
+our $VERSION = '0.07';
 my $AGENT = 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)';
 my $TIMEOUT = 30;
 
 # retirado de http://www.correios.com.br/servicos/rastreamento/internacional/siglas.cfm
+# as siglas DH e JH existem e são utilizadas pelos correios. Porém não
+# encontramos o seu significado no site. Deixamos como DESCONHECIDO
+# até conseguirmos uma resposta concreta sobre o significado destas
+# siglas
 my %siglas = (
   AL => 'AGENTES DE LEITURA',
   AR => 'AVISO DE RECEBIMENTO',
@@ -63,6 +67,7 @@ my %siglas = (
   DD => 'DEVOLUÇÃO DE DOCUMENTOS',
   DE => 'REMESSA EXPRESSA TALÃO E CARTÃO C/ AR',
   DF => 'E-SEDEX (LÓGICO)',
+  DG => 'DESCONHECIDO',
   DI => 'REM EXPRES COM AR DIGITAL ITAU',
   DL => 'ENCOMENDA SEDEX (LÓGICO)',
   DP => 'REM EXPRES COM AR DIGITAL PRF',
@@ -121,6 +126,7 @@ my %siglas = (
   JD => 'REMESSA ECONOMICA C/AR DIGITAL',
   JE => 'REMESSA ECONÔMICA C/AR DIGITAL',
   JG => 'REGISTRATO AGÊNCIA (FÍSICO)',
+  JH => 'DESCONHECIDO',
   JJ => 'REGISTRADO JUSTIÇA',
   JL => 'OBJETO REGISTRADO (LÓGICO)',
   JM => 'MALA DIRETA POSTAL ESPECIAL (LÓGICO)',
@@ -260,7 +266,13 @@ sub _sro {
     return unless $response->is_success;
 
     my $html = HTML::TreeBuilder->new_from_content( $response->decoded_content );
-    my @items = $html->find('table')->find('tr');
+    
+    my $table = $html->find('table');
+    
+    return unless $table;
+    
+    my @items = $table->find('tr');
+
     shift @items; # drop the first 'tr'
 
     my $i = 0;
@@ -338,10 +350,10 @@ English API:
 
     my $last = sro_en( $code );
 
-    $ultimo->date;       # '22/05/2010 12:10'
-    $ultimo->location;   # 'CEE JACAREPAGUA - RIO DE JANEIRO/RJ'
-    $ultimo->status;     # 'No receiver at the address'
-    $ultimo->extra;      # 'Delivery will be retried'
+    $last->date;       # '22/05/2010 12:10'
+    $last->location;   # 'CEE JACAREPAGUA - RIO DE JANEIRO/RJ'
+    $last->status;     # 'No receiver at the address'
+    $last->extra;      # 'Delivery will be retried'
 
 Note: All messages are created by the brazilian post office website. Some messages might not be translated.
 
